# please insert nothing before this line: -*- mode: cperl; cperl-indent-level: 4; cperl-continued-statement-offset: 4; indent-tabs-mode: nil -*-
use strict;
use warnings FATAL => 'all';

use Apache::Test;
use Apache::TestUtil;
use Apache::TestRequest;

my $module = 'TestModules::proxy';
my $url    = Apache::TestRequest::module2url($module);

t_debug("connecting to $url");

my @modules = qw(mod_proxy proxy_http.c);
push @modules, 'mod_access_compat' if have_min_apache_version("2.4.0");
plan tests => 1, need need_module(@modules), need_access;

my $expected = "ok";
my $received = GET_BODY_ASSERT $url;
ok t_cmp($received, $expected, "internally proxified request");
